| Title: | Correct the Spelling of a Given Word in the English Language |
|---|---|
| Description: | Corrects the spelling of a given word in English using a modification of Peter Norvig's spell correct algorithm (see <http://norvig.com/spell-correct.html>) which handles up to three edits. The algorithm tries to find the spelling with maximum probability of intended correction out of all possible candidate corrections from the original word. |
| Authors: | Selva Prabhakaran |
| Maintainer: | Selva Prabhakaran <[email protected]> |
| License: | GPL-2 | GPL-3 |
| Version: | 0.1.2 |
| Built: | 2026-06-07 08:26:54 UTC |
| Source: | https://github.com/cran/spellcheckr |
Correct the spelling of a given word in the english language.
correct(wd = NULL, maxedit = 2, dictionary = NULL)correct(wd = NULL, maxedit = 2, dictionary = NULL)
wd |
Character. The word to be spell corrected. |
maxedit |
Integer. The maximum number of edits allowed to reach the correct word. Max allowed is 3. |
dictionary |
Character Vector of eligible words to be considered. Repeated words will get more weightage. |
This is based on Peter Norvig's spell correct algorithm http://norvig.com/spell.py. But this one is modified to handle upto three edits.
The corrected word.
Selva Prabhakaran [email protected]
data(dict) correct("scaret") correct("beliebe")data(dict) correct("scaret") correct("beliebe")
A dataset containing the valid english dictionary words originally obtained from a work of Jane Austen.
data(dict)data(dict)
A data frame with 245462 rows and 2 columns
. The actual word
N The number of occurences of the word in the document.